<?php
/*
 You may not change or alter any portion of this comment or credits
 of supporting developers from this source code or any supporting source code
 which is considered copyrighted (c) material of the original comment or credit authors.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*/

/**
 * Team module for xoops
 *
 * @copyright      2020 XOOPS Project (https://xooops.org)
 * @license        GPL 2.0 or later
 * @package        team
 * @since          1.0
 * @min_xoops      2.5.9
 * @author         B.Heyula - Email:<b.heyula@hotmail.com> - Website:<http://erenyumak.com>
 */

use Xmf\Request;
use XoopsModules\Team;
use XoopsModules\Team\Constants;

require __DIR__ . '/header.php';

// Template Index
$templateMain = 'team_admin_permissions.tpl';
$GLOBALS['xoopsTpl']->assign('navigation', $adminObject->displayNavigation('permissions.php'));

$op = Request::getCmd('op', 'global');

// Get Form
include_once XOOPS_ROOT_PATH . '/class/xoopsform/grouppermform.php';
\xoops_load('XoopsFormLoader');
$permTableForm = new \XoopsSimpleForm('', 'fselperm', 'permissions.php', 'post');
$formSelect = new \XoopsFormSelect('', 'op', $op);
$formSelect->setExtra('onchange="document.fselperm.submit()"');
$formSelect->addOption('global', _AM_TEAM_PERMISSIONS_GLOBAL);
$formSelect->addOption('approve_teams', _AM_TEAM_PERMISSIONS_APPROVE . ' Teams');
$formSelect->addOption('submit_teams', _AM_TEAM_PERMISSIONS_SUBMIT . ' Teams');
$formSelect->addOption('view_teams', _AM_TEAM_PERMISSIONS_VIEW . ' Teams');
$permTableForm->addElement($formSelect);
$permTableForm->display();
switch ($op) {
	case 'global':
	default:
		$formTitle = _AM_TEAM_PERMISSIONS_GLOBAL;
		$permName = 'team_ac';
		$permDesc = _AM_TEAM_PERMISSIONS_GLOBAL_DESC;
		$globalPerms = array( '4' => _AM_TEAM_PERMISSIONS_GLOBAL_4, '8' => _AM_TEAM_PERMISSIONS_GLOBAL_8, '16' => _AM_TEAM_PERMISSIONS_GLOBAL_16 );
		break;
	case 'approve_teams':
		$formTitle = _AM_TEAM_PERMISSIONS_APPROVE;
		$permName = 'team_approve_teams';
		$permDesc = _AM_TEAM_PERMISSIONS_APPROVE_DESC . ' Teams';
		$handler = $helper->getHandler('teams');
		break;
	case 'submit_teams':
		$formTitle = _AM_TEAM_PERMISSIONS_SUBMIT;
		$permName = 'team_submit_teams';
		$permDesc = _AM_TEAM_PERMISSIONS_SUBMIT_DESC . ' Teams';
		$handler = $helper->getHandler('teams');
		break;
	case 'view_teams':
		$formTitle = _AM_TEAM_PERMISSIONS_VIEW;
		$permName = 'team_view_teams';
		$permDesc = _AM_TEAM_PERMISSIONS_VIEW_DESC . ' Teams';
		$handler = $helper->getHandler('teams');
		break;
}
$moduleId = $xoopsModule->getVar('mid');
$permform = new \XoopsGroupPermForm($formTitle, $moduleId, $permName, $permDesc, 'admin/permissions.php');
$permFound = false;
if ('global' === $op) {
	foreach ($globalPerms as $gPermId => $gPermName) {
		$permform->addItem($gPermId, $gPermName);
	}
	$GLOBALS['xoopsTpl']->assign('form', $permform->render());
	$permFound = true;
}
if ($op === 'approve_teams' || $op === 'submit_teams' || $op === 'view_teams') {
	$teamsCount = $teamsHandler->getCountTeams();
	if ($teamsCount > 0) {
		$teamsAll = $teamsHandler->getAllTeams(0, 'tea_title');
		foreach (\array_keys($teamsAll) as $i) {
			$permform->addItem($teamsAll[$i]->getVar('tea_id'), $teamsAll[$i]->getVar('tea_title'));
		}
		$GLOBALS['xoopsTpl']->assign('form', $permform->render());
	}
	$permFound = true;
}
unset($permform);
if (true !== $permFound) {
	\redirect_header('permissions.php', 3, _AM_TEAM_NO_PERMISSIONS_SET);
	exit();
}
require __DIR__ . '/footer.php';
