<?php
/*
 You may not change or alter any portion of this comment or credits
 of supporting developers from this source code or any supporting source code
 which is considered copyrighted (c) material of the original comment or credit authors.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*/

/**
 * Team module for xoops
 *
 * @copyright      2020 XOOPS Project (https://xooops.org)
 * @license        GPL 2.0 or later
 * @package        team
 * @since          1.0
 * @min_xoops      2.5.9
 * @author         B.Heyula - Email:<b.heyula@hotmail.com> - Website:<http://erenyumak.com>
 */

use Xmf\Request;
use XoopsModules\Team;
use XoopsModules\Team\Constants;
use XoopsModules\Team\Common;

require __DIR__ . '/header.php';
// It recovered the value of argument op in URL$
$op = Request::getCmd('op', 'list');
// Request tea_id
$teaId = Request::getInt('tea_id');
switch ($op) {
	case 'list':
	default:
		// Define Stylesheet
		$GLOBALS['xoTheme']->addStylesheet($style, null);
		$start = Request::getInt('start', 0);
		$limit = Request::getInt('limit', $helper->getConfig('adminpager'));
		$templateMain = 'team_admin_teams.tpl';
		$GLOBALS['xoopsTpl']->assign('navigation', $adminObject->displayNavigation('teams.php'));
		$adminObject->addItemButton(_AM_TEAM_ADD_TEAM, 'teams.php?op=new', 'add');
		$GLOBALS['xoopsTpl']->assign('buttons', $adminObject->displayButton('left'));
		$teamsCount = $teamsHandler->getCountTeams();
		$teamsAll = $teamsHandler->getAllTeams($start, $limit);
		$GLOBALS['xoopsTpl']->assign('teams_count', $teamsCount);
		$GLOBALS['xoopsTpl']->assign('team_url', TEAM_URL);
		$GLOBALS['xoopsTpl']->assign('team_upload_url', TEAM_UPLOAD_URL);
		// Table view teams
		if ($teamsCount > 0) {
			foreach (\array_keys($teamsAll) as $i) {
				$team = $teamsAll[$i]->getValuesTeams();
				$GLOBALS['xoopsTpl']->append('teams_list', $team);
				unset($team);
			}
			// Display Navigation
			if ($teamsCount > $limit) {
				include_once XOOPS_ROOT_PATH . '/class/pagenav.php';
				$pagenav = new \XoopsPageNav($teamsCount, $limit, $start, 'start', 'op=list&limit=' . $limit);
				$GLOBALS['xoopsTpl']->assign('pagenav', $pagenav->renderNav(4));
			}
		} else {
			$GLOBALS['xoopsTpl']->assign('error', _AM_TEAM_THEREARENT_TEAMS);
		}
		break;
	case 'new':
		$templateMain = 'team_admin_teams.tpl';
		$GLOBALS['xoopsTpl']->assign('navigation', $adminObject->displayNavigation('teams.php'));
		$adminObject->addItemButton(_AM_TEAM_TEAMS_LIST, 'teams.php', 'list');
		$GLOBALS['xoopsTpl']->assign('buttons', $adminObject->displayButton('left'));
		// Form Create
		$teamsObj = $teamsHandler->create();
		$form = $teamsObj->getFormTeams();
		$GLOBALS['xoopsTpl']->assign('form', $form->render());
		break;
	case 'save':
		// Security Check
		if (!$GLOBALS['xoopsSecurity']->check()) {
			\redirect_header('teams.php', 3, \implode(',', $GLOBALS['xoopsSecurity']->getErrors()));
		}
		if ($teaId > 0) {
			$teamsObj = $teamsHandler->get($teaId);
		} else {
			$teamsObj = $teamsHandler->create();
		}
		// Set Vars
		$teamsObj->setVar('tea_title', Request::getString('tea_title', ''));
		$teamsObj->setVar('tea_name', Request::getString('tea_name', ''));
		$teamsObj->setVar('tea_mission', Request::getString('tea_mission', ''));
		$teamsObj->setVar('tea_about', Request::getText('tea_about', ''));
		// Set Var tea_picture
		include_once XOOPS_ROOT_PATH . '/class/uploader.php';
		$filename       = $_FILES['tea_picture']['name'];
		$imgMimetype    = $_FILES['tea_picture']['type'];
		$imgNameDef     = Request::getString('tea_title');
		$uploaderErrors = '';
		$uploader = new \XoopsMediaUploader(TEAM_UPLOAD_IMAGE_PATH . '/teams/', 
													$helper->getConfig('mimetypes_image'), 
													$helper->getConfig('maxsize_image'), null, null);
		if ($uploader->fetchMedia($_POST['xoops_upload_file'][0])) {
			$extension = \preg_replace('/^.+\.([^.]+)$/sU', '', $filename);
			$imgName = \str_replace(' ', '', $imgNameDef) . '.' . $extension;
			$uploader->setPrefix($imgName);
			$uploader->fetchMedia($_POST['xoops_upload_file'][0]);
			if (!$uploader->upload()) {
				$uploaderErrors = $uploader->getErrors();
			} else {
				$savedFilename = $uploader->getSavedFileName();
				$maxwidth  = (int)$helper->getConfig('maxwidth_image');
				$maxheight = (int)$helper->getConfig('maxheight_image');
				if ($maxwidth > 0 && $maxheight > 0) {
					// Resize image
					$imgHandler                = new Team\Common\Resizer();
					$imgHandler->sourceFile    = TEAM_UPLOAD_IMAGE_PATH . '/teams/' . $savedFilename;
					$imgHandler->endFile       = TEAM_UPLOAD_IMAGE_PATH . '/teams/' . $savedFilename;
					$imgHandler->imageMimetype = $imgMimetype;
					$imgHandler->maxWidth      = $maxwidth;
					$imgHandler->maxHeight     = $maxheight;
					$result                    = $imgHandler->resizeImage();
				}
				$teamsObj->setVar('tea_picture', $savedFilename);
			}
		} else {
			if ($filename > '') {
				$uploaderErrors = $uploader->getErrors();
			}
			$teamsObj->setVar('tea_picture', Request::getString('tea_picture'));
		}
		$teamDateObj = \DateTime::createFromFormat(_SHORTDATESTRING, Request::getString('tea_date'));
		$teamsObj->setVar('tea_date', $teamDateObj->getTimestamp());
		// Insert Data
		if ($teamsHandler->insert($teamsObj)) {
			$newTeaId = $teamsObj->getNewInsertedIdTeams();
			$permId = isset($_REQUEST['tea_id']) ? $teaId : $newTeaId;
			$grouppermHandler = \xoops_getHandler('groupperm');
			$mid = $GLOBALS['xoopsModule']->getVar('mid');
			// Permission to view_teams
			$grouppermHandler->deleteByModule($mid, 'team_view_teams', $permId);
			if (isset($_POST['groups_view_teams'])) {
				foreach ($_POST['groups_view_teams'] as $onegroupId) {
					$grouppermHandler->addRight('team_view_teams', $permId, $onegroupId, $mid);
				}
			}
			// Permission to submit_teams
			$grouppermHandler->deleteByModule($mid, 'team_submit_teams', $permId);
			if (isset($_POST['groups_submit_teams'])) {
				foreach ($_POST['groups_submit_teams'] as $onegroupId) {
					$grouppermHandler->addRight('team_submit_teams', $permId, $onegroupId, $mid);
				}
			}
			// Permission to approve_teams
			$grouppermHandler->deleteByModule($mid, 'team_approve_teams', $permId);
			if (isset($_POST['groups_approve_teams'])) {
				foreach ($_POST['groups_approve_teams'] as $onegroupId) {
					$grouppermHandler->addRight('team_approve_teams', $permId, $onegroupId, $mid);
				}
			}
			if ('' !== $uploaderErrors) {
				\redirect_header('teams.php?op=edit&tea_id=' . $teaId, 5, $uploaderErrors);
			} else {
				\redirect_header('teams.php?op=list', 2, _AM_TEAM_FORM_OK);
			}
		}
		// Get Form
		$GLOBALS['xoopsTpl']->assign('error', $teamsObj->getHtmlErrors());
		$form = $teamsObj->getFormTeams();
		$GLOBALS['xoopsTpl']->assign('form', $form->render());
		break;
	case 'edit':
		$templateMain = 'team_admin_teams.tpl';
		$GLOBALS['xoopsTpl']->assign('navigation', $adminObject->displayNavigation('teams.php'));
		$adminObject->addItemButton(_AM_TEAM_ADD_TEAM, 'teams.php?op=new', 'add');
		$adminObject->addItemButton(_AM_TEAM_TEAMS_LIST, 'teams.php', 'list');
		$GLOBALS['xoopsTpl']->assign('buttons', $adminObject->displayButton('left'));
		// Get Form
		$teamsObj = $teamsHandler->get($teaId);
		$form = $teamsObj->getFormTeams();
		$GLOBALS['xoopsTpl']->assign('form', $form->render());
		break;
	case 'delete':
		$templateMain = 'team_admin_teams.tpl';
		$GLOBALS['xoopsTpl']->assign('navigation', $adminObject->displayNavigation('teams.php'));
		$teamsObj = $teamsHandler->get($teaId);
		$teaTitle = $teamsObj->getVar('tea_title');
		if (isset($_REQUEST['ok']) && 1 == $_REQUEST['ok']) {
			if (!$GLOBALS['xoopsSecurity']->check()) {
				\redirect_header('teams.php', 3, \implode(', ', $GLOBALS['xoopsSecurity']->getErrors()));
			}
			if ($teamsHandler->delete($teamsObj)) {
				\redirect_header('teams.php', 3, _AM_TEAM_FORM_DELETE_OK);
			} else {
				$GLOBALS['xoopsTpl']->assign('error', $teamsObj->getHtmlErrors());
			}
		} else {
			$xoopsconfirm = new Common\XoopsConfirm(
				['ok' => 1, 'tea_id' => $teaId, 'op' => 'delete'],
				$_SERVER['REQUEST_URI'],
				\sprintf(_AM_TEAM_FORM_SURE_DELETE, $teamsObj->getVar('tea_title')));
			$form = $xoopsconfirm->getFormXoopsConfirm();
			$GLOBALS['xoopsTpl']->assign('form', $form->render());
		}
		break;
}
require __DIR__ . '/footer.php';
