<?php
/*
 You may not change or alter any portion of this comment or credits
 of supporting developers from this source code or any supporting source code
 which is considered copyrighted (c) material of the original comment or credit authors.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*/

/**
 * Team module for xoops
 *
 * @copyright      2020 XOOPS Project (https://xooops.org)
 * @license        GPL 2.0 or later
 * @package        team
 * @since          1.0
 * @min_xoops      2.5.9
 * @author         B.Heyula - Email:<b.heyula@hotmail.com> - Website:<http://erenyumak.com>
 */

use XoopsModules\Team;
use XoopsModules\Team\Helper;
use XoopsModules\Team\Constants;

include_once XOOPS_ROOT_PATH . '/modules/team/include/common.php';

/**
 * Function show block
 * @param  $options
 * @return array
 */
function b_team_teams_show($options)
{
	include_once XOOPS_ROOT_PATH . '/modules/team/class/teams.php';
	$myts = MyTextSanitizer::getInstance();
	$GLOBALS['xoopsTpl']->assign('team_upload_url', TEAM_UPLOAD_URL);
	$block       = [];
	$typeBlock   = $options[0];
	$limit       = $options[1];
	$lenghtTitle = $options[2];
	$helper      = Helper::getInstance();
	$teamsHandler = $helper->getHandler('Teams');
	$crTeams = new \CriteriaCompo();
	\array_shift($options);
	\array_shift($options);
	\array_shift($options);

	switch ($typeBlock) {
		case 'last':
		default:
			// For the block: teams last
			$crTeams->setSort('tea_date');
			$crTeams->setOrder('DESC');
			break;
		case 'new':
			// For the block: teams new
			$crTeams->add(new \Criteria('tea_date', \DateTime::createFromFormat(_SHORTDATESTRING), '>='));
			$crTeams->add(new \Criteria('tea_date', \DateTime::createFromFormat(_SHORTDATESTRING) + 86400, '<='));
			$crTeams->setSort('tea_date');
			$crTeams->setOrder('ASC');
			break;
		case 'hits':
			// For the block: teams hits
			$crTeams->setSort('tea_hits');
			$crTeams->setOrder('DESC');
			break;
		case 'top':
			// For the block: teams top
			$crTeams->setSort('tea_top');
			$crTeams->setOrder('ASC');
			break;
		case 'random':
			// For the block: teams random
			$crTeams->setSort('RAND()');
			break;
	}

	$crTeams->setLimit($limit);
	$teamsAll = $teamsHandler->getAll($crTeams);
	unset($crTeams);
	if (\count($teamsAll) > 0) {
		foreach (\array_keys($teamsAll) as $i) {
			$block[$i]['title'] = $myts->htmlSpecialChars($teamsAll[$i]->getVar('tea_title'));
			$block[$i]['name'] = $myts->htmlSpecialChars($teamsAll[$i]->getVar('tea_name'));
			$block[$i]['mission'] = $myts->htmlSpecialChars($teamsAll[$i]->getVar('tea_mission'));
			$block[$i]['about'] = \strip_tags($teamsAll[$i]->getVar('tea_about'));
			$block[$i]['picture'] = $teamsAll[$i]->getVar('tea_picture');
			$block[$i]['date'] = \formatTimestamp($teamsAll[$i]->getVar('tea_date'));
		}
	}

	return $block;

}

/**
 * Function edit block
 * @param  $options
 * @return string
 */
function b_team_teams_edit($options)
{
	include_once XOOPS_ROOT_PATH . '/modules/team/class/teams.php';
	$helper = Helper::getInstance();
	$teamsHandler = $helper->getHandler('Teams');
	$GLOBALS['xoopsTpl']->assign('team_upload_url', TEAM_UPLOAD_URL);
	$form = _MB_TEAM_DISPLAY;
	$form .= "<input type='hidden' name='options[0]' value='".$options[0]."' />";
	$form .= "<input type='text' name='options[1]' size='5' maxlength='255' value='" . $options[1] . "' />&nbsp;<br>";
	$form .= _MB_TEAM_TITLE_LENGTH . " : <input type='text' name='options[2]' size='5' maxlength='255' value='" . $options[2] . "' /><br><br>";
	\array_shift($options);
	\array_shift($options);
	\array_shift($options);

	$crTeams = new \CriteriaCompo();
	$crTeams->add(new \Criteria('tea_id', 0, '!='));
	$crTeams->setSort('tea_id');
	$crTeams->setOrder('ASC');
	$teamsAll = $teamsHandler->getAll($crTeams);
	unset($crTeams);
	$form .= _MB_TEAM_TEAMS_TO_DISPLAY . "<br><select name='options[]' multiple='multiple' size='5'>";
	$form .= "<option value='0' " . (\in_array(0, $options) == false ? '' : "selected='selected'") . '>' . _MB_TEAM_ALL_TEAMS . '</option>';
	foreach (\array_keys($teamsAll) as $i) {
		$tea_id = $teamsAll[$i]->getVar('tea_id');
		$form .= "<option value='" . $tea_id . "' " . (\in_array($tea_id, $options) == false ? '' : "selected='selected'") . '>' . $teamsAll[$i]->getVar('tea_title') . '</option>';
	}
	$form .= '</select>';

	return $form;

}
