<?php

namespace XoopsModules\Team;

/*
 You may not change or alter any portion of this comment or credits
 of supporting developers from this source code or any supporting source code
 which is considered copyrighted (c) material of the original comment or credit authors.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*/

/**
 * Team module for xoops
 *
 * @copyright      2020 XOOPS Project (https://xooops.org)
 * @license        GPL 2.0 or later
 * @package        team
 * @since          1.0
 * @min_xoops      2.5.9
 * @author         B.Heyula - Email:<b.heyula@hotmail.com> - Website:<http://erenyumak.com>
 */

use XoopsModules\Team;

\defined('XOOPS_ROOT_PATH') || die('Restricted access');

/**
 * Class Object Teams
 */
class Teams extends \XoopsObject
{
	/**
	 * Constructor
	 *
	 * @param null
	 */
	public function __construct()
	{
		$this->initVar('tea_id', XOBJ_DTYPE_INT);
		$this->initVar('tea_title', XOBJ_DTYPE_TXTBOX);
		$this->initVar('tea_name', XOBJ_DTYPE_TXTBOX);
		$this->initVar('tea_mission', XOBJ_DTYPE_TXTBOX);
		$this->initVar('tea_about', XOBJ_DTYPE_OTHER);
		$this->initVar('tea_picture', XOBJ_DTYPE_TXTBOX);
		$this->initVar('tea_date', XOBJ_DTYPE_INT);
	}

	/**
	 * @static function &getInstance
	 *
	 * @param null
	 */
	public static function getInstance()
	{
		static $instance = false;
		if (!$instance) {
			$instance = new self();
		}
	}

	/**
	 * The new inserted $Id
	 * @return inserted id
	 */
	public function getNewInsertedIdTeams()
	{
		$newInsertedId = $GLOBALS['xoopsDB']->getInsertId();
		return $newInsertedId;
	}

	/**
	 * @public function getForm
	 * @param bool $action
	 * @return \XoopsThemeForm
	 */
	public function getFormTeams($action = false)
	{
		$helper = \XoopsModules\Team\Helper::getInstance();
		if (!$action) {
			$action = $_SERVER['REQUEST_URI'];
		}
		$isAdmin = $GLOBALS['xoopsUser']->isAdmin($GLOBALS['xoopsModule']->mid());
		// Permissions for uploader
		$grouppermHandler = \xoops_getHandler('groupperm');
		$groups = \is_object($GLOBALS['xoopsUser']) ? $GLOBALS['xoopsUser']->getGroups() : XOOPS_GROUP_ANONYMOUS;
		$permissionUpload = $grouppermHandler->checkRight('upload_groups', 32, $groups, $GLOBALS['xoopsModule']->getVar('mid')) ? true : false;
		// Title
		$title = $this->isNew() ? \sprintf(_AM_TEAM_TEAM_ADD) : \sprintf(_AM_TEAM_TEAM_EDIT);
		// Get Theme Form
		\xoops_load('XoopsFormLoader');
		$form = new \XoopsThemeForm($title, 'form', $action, 'post', true);
		$form->setExtra('enctype="multipart/form-data"');
		// Form Text teaTitle
		$form->addElement(new \XoopsFormText(_AM_TEAM_TEAM_TITLE, 'tea_title', 50, 255, $this->getVar('tea_title')));
		// Form Text teaName
		$form->addElement(new \XoopsFormText(_AM_TEAM_TEAM_NAME, 'tea_name', 50, 255, $this->getVar('tea_name')));
		// Form Text teaMission
		$form->addElement(new \XoopsFormText(_AM_TEAM_TEAM_MISSION, 'tea_mission', 50, 255, $this->getVar('tea_mission')));
		// Form Editor DhtmlTextArea teaAbout
		$editorConfigs = [];
		if ($isAdmin) {
			$editor = $helper->getConfig('editor_admin');
		} else {
			$editor = $helper->getConfig('editor_user');
		}
		$editorConfigs['name'] = 'tea_about';
		$editorConfigs['value'] = $this->getVar('tea_about', 'e');
		$editorConfigs['rows'] = 5;
		$editorConfigs['cols'] = 40;
		$editorConfigs['width'] = '100%';
		$editorConfigs['height'] = '400px';
		$editorConfigs['editor'] = $editor;
		$form->addElement(new \XoopsFormEditor(_AM_TEAM_TEAM_ABOUT, 'tea_about', $editorConfigs));
		// Form Image teaPicture
		// Form Image teaPicture: Select Uploaded Image 
		$getTeaPicture = $this->getVar('tea_picture');
		$teaPicture = $getTeaPicture ?: 'blank.gif';
		$imageDirectory = '/uploads/team/images/teams';
		$imageTray = new \XoopsFormElementTray(_AM_TEAM_TEAM_PICTURE, '<br>');
		$imageSelect = new \XoopsFormSelect(\sprintf(_AM_TEAM_TEAM_PICTURE_UPLOADS, ".{$imageDirectory}/"), 'tea_picture', $teaPicture, 5);
		$imageArray = \XoopsLists::getImgListAsArray( XOOPS_ROOT_PATH . $imageDirectory );
		foreach ($imageArray as $image1) {
			$imageSelect->addOption((string)($image1), $image1);
		}
		$imageSelect->setExtra("onchange='showImgSelected(\"imglabel_tea_picture\", \"tea_picture\", \"" . $imageDirectory . '", "", "' . XOOPS_URL . "\")'");
		$imageTray->addElement($imageSelect, false);
		$imageTray->addElement(new \XoopsFormLabel('', "<br><img src='" . XOOPS_URL . '/' . $imageDirectory . '/' . $teaPicture . "' id='imglabel_tea_picture' alt='' style='max-width:100px' />"));
		// Form Image teaPicture: Upload new image
		if ($permissionUpload) {
			$maxsize = $helper->getConfig('maxsize_image');
			$imageTray->addElement(new \XoopsFormFile('<br>' . _AM_TEAM_FORM_UPLOAD_NEW, 'tea_picture', $maxsize));
			$imageTray->addElement(new \XoopsFormLabel(_AM_TEAM_FORM_UPLOAD_SIZE, ($maxsize / 1048576) . ' '  . _AM_TEAM_FORM_UPLOAD_SIZE_MB));
			$imageTray->addElement(new \XoopsFormLabel(_AM_TEAM_FORM_UPLOAD_IMG_WIDTH, $helper->getConfig('maxwidth_image') . ' px'));
			$imageTray->addElement(new \XoopsFormLabel(_AM_TEAM_FORM_UPLOAD_IMG_HEIGHT, $helper->getConfig('maxheight_image') . ' px'));
		} else {
			$imageTray->addElement(new \XoopsFormHidden('tea_picture', $teaPicture));
		}
		$form->addElement($imageTray);
		// Form Text Date Select teaDate
		$teaDate = $this->isNew() ?: $this->getVar('tea_date');
		$form->addElement(new \XoopsFormTextDateSelect(_AM_TEAM_TEAM_DATE, 'tea_date', '', $teaDate));
		// Permissions
		$memberHandler = \xoops_getHandler('member');
		$groupList = $memberHandler->getGroupList();
		$grouppermHandler = \xoops_getHandler('groupperm');
		$fullList[] = \array_keys($groupList);
		if (!$this->isNew()) {
			$groupsIdsApprove = $grouppermHandler->getGroupIds('team_approve_teams', $this->getVar('tea_id'), $GLOBALS['xoopsModule']->getVar('mid'));
			$groupsIdsApprove[] = \array_values($groupsIdsApprove);
			$groupsCanApproveCheckbox = new \XoopsFormCheckBox(_AM_TEAM_PERMISSIONS_APPROVE, 'groups_approve_teams[]', $groupsIdsApprove);
			$groupsIdsSubmit = $grouppermHandler->getGroupIds('team_submit_teams', $this->getVar('tea_id'), $GLOBALS['xoopsModule']->getVar('mid'));
			$groupsIdsSubmit[] = \array_values($groupsIdsSubmit);
			$groupsCanSubmitCheckbox = new \XoopsFormCheckBox(_AM_TEAM_PERMISSIONS_SUBMIT, 'groups_submit_teams[]', $groupsIdsSubmit);
			$groupsIdsView = $grouppermHandler->getGroupIds('team_view_teams', $this->getVar('tea_id'), $GLOBALS['xoopsModule']->getVar('mid'));
			$groupsIdsView[] = \array_values($groupsIdsView);
			$groupsCanViewCheckbox = new \XoopsFormCheckBox(_AM_TEAM_PERMISSIONS_VIEW, 'groups_view_teams[]', $groupsIdsView);
		} else {
			$groupsCanApproveCheckbox = new \XoopsFormCheckBox(_AM_TEAM_PERMISSIONS_APPROVE, 'groups_approve_teams[]', $fullList);
			$groupsCanSubmitCheckbox = new \XoopsFormCheckBox(_AM_TEAM_PERMISSIONS_SUBMIT, 'groups_submit_teams[]', $fullList);
			$groupsCanViewCheckbox = new \XoopsFormCheckBox(_AM_TEAM_PERMISSIONS_VIEW, 'groups_view_teams[]', $fullList);
		}
		// To Approve
		$groupsCanApproveCheckbox->addOptionArray($groupList);
		$form->addElement($groupsCanApproveCheckbox);
		// To Submit
		$groupsCanSubmitCheckbox->addOptionArray($groupList);
		$form->addElement($groupsCanSubmitCheckbox);
		// To View
		$groupsCanViewCheckbox->addOptionArray($groupList);
		$form->addElement($groupsCanViewCheckbox);
		// To Save
		$form->addElement(new \XoopsFormHidden('op', 'save'));
		$form->addElement(new \XoopsFormButtonTray('', _SUBMIT, 'submit', '', false));
		return $form;
	}

	/**
	 * Get Values
	 * @param null $keys
	 * @param null $format
	 * @param null $maxDepth
	 * @return array
	 */
	public function getValuesTeams($keys = null, $format = null, $maxDepth = null)
	{
		$helper  = \XoopsModules\Team\Helper::getInstance();
		$utility = new \XoopsModules\Team\Utility();
		$ret = $this->getValues($keys, $format, $maxDepth);
		$ret['id']          = $this->getVar('tea_id');
		$ret['title']       = $this->getVar('tea_title');
		$ret['name']        = $this->getVar('tea_name');
		$ret['mission']     = $this->getVar('tea_mission');
		$ret['about']       = $this->getVar('tea_about', 'e');
		$editorMaxchar = $helper->getConfig('editor_maxchar');
		$ret['about_short'] = $utility::truncateHtml($ret['about'], $editorMaxchar);
		$ret['picture']     = $this->getVar('tea_picture');
		$ret['date']        = \formatTimestamp($this->getVar('tea_date'), 's');
		return $ret;
	}

	/**
	 * Returns an array representation of the object
	 *
	 * @return array
	 */
	public function toArrayTeams()
	{
		$ret = [];
		$vars = $this->getVars();
		foreach (\array_keys($vars) as $var) {
			$ret[$var] = $this->getVar('"{$var}"');
		}
		return $ret;
	}
}
