<?php

namespace XoopsModules\Team;

/*
 You may not change or alter any portion of this comment or credits
 of supporting developers from this source code or any supporting source code
 which is considered copyrighted (c) material of the original comment or credit authors.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*/

/**
 * Team module for xoops
 *
 * @copyright      2020 XOOPS Project (https://xooops.org)
 * @license        GPL 2.0 or later
 * @package        team
 * @since          1.0
 * @min_xoops      2.5.9
 * @author         B.Heyula - Email:<b.heyula@hotmail.com> - Website:<http://erenyumak.com>
 */

use XoopsModules\Team;


/**
 * Class Object Handler Teams
 */
class TeamsHandler extends \XoopsPersistableObjectHandler
{
	/**
	 * Constructor
	 *
	 * @param \XoopsDatabase $db
	 */
	public function __construct(\XoopsDatabase $db)
	{
		parent::__construct($db, 'team_teams', Teams::class, 'tea_id', 'tea_title');
	}

	/**
	 * @param bool $isNew
	 *
	 * @return object
	 */
	public function create($isNew = true)
	{
		return parent::create($isNew);
	}

	/**
	 * retrieve a field
	 *
	 * @param int $i field id
	 * @param null fields
	 * @return mixed reference to the {@link Get} object
	 */
	public function get($i = null, $fields = null)
	{
		return parent::get($i, $fields);
	}

	/**
	 * get inserted id
	 *
	 * @param null
	 * @return int reference to the {@link Get} object
	 */
	public function getInsertId()
	{
		return $this->db->getInsertId();
	}

	/**
	 * Get Count Teams in the database
	 * @param int    $start
	 * @param int    $limit
	 * @param string $sort
	 * @param string $order
	 * @return int
	 */
	public function getCountTeams($start = 0, $limit = 0, $sort = 'tea_id ASC, tea_title', $order = 'ASC')
	{
		$crCountTeams = new \CriteriaCompo();
		$crCountTeams = $this->getTeamsCriteria($crCountTeams, $start, $limit, $sort, $order);
		return $this->getCount($crCountTeams);
	}

	/**
	 * Get All Teams in the database
	 * @param int    $start
	 * @param int    $limit
	 * @param string $sort
	 * @param string $order
	 * @return array
	 */
	public function getAllTeams($start = 0, $limit = 0, $sort = 'tea_id ASC, tea_title', $order = 'ASC')
	{
		$crAllTeams = new \CriteriaCompo();
		$crAllTeams = $this->getTeamsCriteria($crAllTeams, $start, $limit, $sort, $order);
		return $this->getAll($crAllTeams);
	}

	/**
	 * Get Criteria Teams
	 * @param        $crTeams
	 * @param int    $start
	 * @param int    $limit
	 * @param string $sort
	 * @param string $order
	 * @return int
	 */
	private function getTeamsCriteria($crTeams, $start, $limit, $sort, $order)
	{
		$crTeams->setStart($start);
		$crTeams->setLimit($limit);
		$crTeams->setSort($sort);
		$crTeams->setOrder($order);
		return $crTeams;
	}
}
