<?php
/*
 You may not change or alter any portion of this comment or credits
 of supporting developers from this source code or any supporting source code
 which is considered copyrighted (c) material of the original comment or credit authors.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*/

/**
 * Team module for xoops
 *
 * @copyright      2020 XOOPS Project (https://xooops.org)
 * @license        GPL 2.0 or later
 * @package        team
 * @since          1.0
 * @min_xoops      2.5.9
 * @author         B.Heyula - Email:<b.heyula@hotmail.com> - Website:<http://erenyumak.com>
 */

use Xmf\Request;
use XoopsModules\Team;
use XoopsModules\Team\Constants;
use XoopsModules\Team\Common;

require __DIR__ . '/header.php';
$GLOBALS['xoopsOption']['template_main'] = 'team_teams.tpl';
include_once XOOPS_ROOT_PATH . '/header.php';

$op    = Request::getCmd('op', 'list');
$start = Request::getInt('start', 0);
$limit = Request::getInt('limit', $helper->getConfig('userpager'));
$teaId = Request::getInt('tea_id', 0);

// Define Stylesheet
$GLOBALS['xoTheme']->addStylesheet($style, null);

$GLOBALS['xoopsTpl']->assign('xoops_icons32_url', XOOPS_ICONS32_URL);
$GLOBALS['xoopsTpl']->assign('team_url', TEAM_URL);

$keywords = [];

$permEdit = $permissionsHandler->getPermGlobalSubmit();
$GLOBALS['xoopsTpl']->assign('permEdit', $permEdit);
$GLOBALS['xoopsTpl']->assign('showItem', $teaId > 0);

switch ($op) {
	case 'show':
	case 'list':
	default:
		$crTeams = new \CriteriaCompo();
		if ($teaId > 0) {
			$crTeams->add(new \Criteria('tea_id', $teaId));
		}
		$teamsCount = $teamsHandler->getCount($crTeams);
		$GLOBALS['xoopsTpl']->assign('teamsCount', $teamsCount);
		$crTeams->setStart($start);
		$crTeams->setLimit($limit);
		$teamsAll = $teamsHandler->getAll($crTeams);
		if ($teamsCount > 0) {
			$teams = [];
			// Get All Teams
			foreach (\array_keys($teamsAll) as $i) {
				$teams[$i] = $teamsAll[$i]->getValuesTeams();
				$keywords[$i] = $teamsAll[$i]->getVar('tea_title');
			}
			$GLOBALS['xoopsTpl']->assign('teams', $teams);
			unset($teams);
			// Display Navigation
			if ($teamsCount > $limit) {
				include_once XOOPS_ROOT_PATH . '/class/pagenav.php';
				$pagenav = new \XoopsPageNav($teamsCount, $limit, $start, 'start', 'op=list&limit=' . $limit);
				$GLOBALS['xoopsTpl']->assign('pagenav', $pagenav->renderNav(4));
			}
			$GLOBALS['xoopsTpl']->assign('type', $helper->getConfig('table_type'));
			$GLOBALS['xoopsTpl']->assign('divideby', $helper->getConfig('divideby'));
			$GLOBALS['xoopsTpl']->assign('numb_col', $helper->getConfig('numb_col'));
		}
		break;
	case 'save':
		// Security Check
		if (!$GLOBALS['xoopsSecurity']->check()) {
			\redirect_header('teams.php', 3, \implode(',', $GLOBALS['xoopsSecurity']->getErrors()));
		}
		// Check permissions
		if (!$permissionsHandler->getPermGlobalSubmit()) {
			\redirect_header('teams.php?op=list', 3, _NOPERM);
		}
		if ($teaId > 0) {
			$teamsObj = $teamsHandler->get($teaId);
		} else {
			$teamsObj = $teamsHandler->create();
		}
		$teamsObj->setVar('tea_title', Request::getString('tea_title', ''));
		$teamsObj->setVar('tea_name', Request::getString('tea_name', ''));
		$teamsObj->setVar('tea_mission', Request::getString('tea_mission', ''));
		$teamsObj->setVar('tea_about', Request::getText('tea_about', ''));
		// Set Var tea_picture
		include_once XOOPS_ROOT_PATH . '/class/uploader.php';
		$filename       = $_FILES['tea_picture']['name'];
		$imgMimetype    = $_FILES['tea_picture']['type'];
		$imgNameDef     = Request::getString('tea_title');
		$uploaderErrors = '';
		$uploader = new \XoopsMediaUploader(TEAM_UPLOAD_IMAGE_PATH . '/teams/', 
													$helper->getConfig('mimetypes_image'), 
													$helper->getConfig('maxsize_image'), null, null);
		if ($uploader->fetchMedia($_POST['xoops_upload_file'][0])) {
			$extension = \preg_replace('/^.+\.([^.]+)$/sU', '', $filename);
			$imgName = \str_replace(' ', '', $imgNameDef) . '.' . $extension;
			$uploader->setPrefix($imgName);
			$uploader->fetchMedia($_POST['xoops_upload_file'][0]);
			if (!$uploader->upload()) {
				$uploaderErrors = $uploader->getErrors();
			} else {
				$savedFilename = $uploader->getSavedFileName();
				$maxwidth  = (int)$helper->getConfig('maxwidth_image');
				$maxheight = (int)$helper->getConfig('maxheight_image');
				if ($maxwidth > 0 && $maxheight > 0) {
					// Resize image
					$imgHandler                = new Team\Common\Resizer();
					$imgHandler->sourceFile    = TEAM_UPLOAD_IMAGE_PATH . '/teams/' . $savedFilename;
					$imgHandler->endFile       = TEAM_UPLOAD_IMAGE_PATH . '/teams/' . $savedFilename;
					$imgHandler->imageMimetype = $imgMimetype;
					$imgHandler->maxWidth      = $maxwidth;
					$imgHandler->maxHeight     = $maxheight;
					$result                    = $imgHandler->resizeImage();
				}
				$teamsObj->setVar('tea_picture', $savedFilename);
			}
		} else {
			if ($filename > '') {
				$uploaderErrors = $uploader->getErrors();
			}
			$teamsObj->setVar('tea_picture', Request::getString('tea_picture'));
		}
		$teamDateObj = \DateTime::createFromFormat(_SHORTDATESTRING, Request::getString('tea_date'));
		$teamsObj->setVar('tea_date', $teamDateObj->getTimestamp());
		// Insert Data
		if ($teamsHandler->insert($teamsObj)) {
			$newTeaId = $teaId > 0 ? $teaId : $teamsObj->getNewInsertedIdTeams();
			$grouppermHandler = \xoops_getHandler('groupperm');
			$mid = $GLOBALS['xoopsModule']->getVar('mid');
			// Permission to view_teams
			$grouppermHandler->deleteByModule($mid, 'team_view_teams', $newTeaId);
			if (isset($_POST['groups_view_teams'])) {
				foreach ($_POST['groups_view_teams'] as $onegroupId) {
					$grouppermHandler->addRight('team_view_teams', $newTeaId, $onegroupId, $mid);
				}
			}
			// Permission to submit_teams
			$grouppermHandler->deleteByModule($mid, 'team_submit_teams', $newTeaId);
			if (isset($_POST['groups_submit_teams'])) {
				foreach ($_POST['groups_submit_teams'] as $onegroupId) {
					$grouppermHandler->addRight('team_submit_teams', $newTeaId, $onegroupId, $mid);
				}
			}
			// Permission to approve_teams
			$grouppermHandler->deleteByModule($mid, 'team_approve_teams', $newTeaId);
			if (isset($_POST['groups_approve_teams'])) {
				foreach ($_POST['groups_approve_teams'] as $onegroupId) {
					$grouppermHandler->addRight('team_approve_teams', $newTeaId, $onegroupId, $mid);
				}
			}
			// redirect after insert
			if ('' !== $uploaderErrors) {
				\redirect_header('teams.php?op=edit&tea_id=' . $newTeaId, 5, $uploaderErrors);
			} else {
				\redirect_header('teams.php?op=list', 2, _MA_TEAM_FORM_OK);
			}
		}
		// Get Form Error
		$GLOBALS['xoopsTpl']->assign('error', $teamsObj->getHtmlErrors());
		$form = $teamsObj->getFormTeams();
		$GLOBALS['xoopsTpl']->assign('form', $form->render());
		break;
	case 'new':
		// Check permissions
		if (!$permissionsHandler->getPermGlobalSubmit()) {
			\redirect_header('teams.php?op=list', 3, _NOPERM);
		}
		// Form Create
		$teamsObj = $teamsHandler->create();
		$form = $teamsObj->getFormTeams();
		$GLOBALS['xoopsTpl']->assign('form', $form->render());
		break;
	case 'edit':
		// Check permissions
		if (!$permissionsHandler->getPermGlobalSubmit()) {
			\redirect_header('teams.php?op=list', 3, _NOPERM);
		}
		// Check params
		if (0 == $teaId) {
			\redirect_header('teams.php?op=list', 3, _MA_TEAM_INVALID_PARAM);
		}
		// Get Form
		$teamsObj = $teamsHandler->get($teaId);
		$form = $teamsObj->getFormTeams();
		$GLOBALS['xoopsTpl']->assign('form', $form->render());
		break;
	case 'delete':
		// Check permissions
		if (!$permissionsHandler->getPermGlobalSubmit()) {
			\redirect_header('teams.php?op=list', 3, _NOPERM);
		}
		// Check params
		if (0 == $teaId) {
			\redirect_header('teams.php?op=list', 3, _MA_TEAM_INVALID_PARAM);
		}
		$teamsObj = $teamsHandler->get($teaId);
		$teaTitle = $teamsObj->getVar('tea_title');
		if (isset($_REQUEST['ok']) && 1 == $_REQUEST['ok']) {
			if (!$GLOBALS['xoopsSecurity']->check()) {
				\redirect_header('teams.php', 3, \implode(', ', $GLOBALS['xoopsSecurity']->getErrors()));
			}
			if ($teamsHandler->delete($teamsObj)) {
				\redirect_header('teams.php', 3, _MA_TEAM_FORM_DELETE_OK);
			} else {
				$GLOBALS['xoopsTpl']->assign('error', $teamsObj->getHtmlErrors());
			}
		} else {
			$xoopsconfirm = new Common\XoopsConfirm(
				['ok' => 1, 'tea_id' => $teaId, 'op' => 'delete'],
				$_SERVER['REQUEST_URI'],
				\sprintf(_MA_TEAM_FORM_SURE_DELETE, $teamsObj->getVar('tea_title')));
			$form = $xoopsconfirm->getFormXoopsConfirm();
			$GLOBALS['xoopsTpl']->assign('form', $form->render());
		}
		break;
}

// Breadcrumbs
$xoBreadcrumbs[] = ['title' => _MA_TEAM_TEAMS];

// Keywords
teamMetaKeywords($helper->getConfig('keywords') . ', ' . \implode(',', $keywords));
unset($keywords);

// Description
teamMetaDescription(_MA_TEAM_TEAMS_DESC);
$GLOBALS['xoopsTpl']->assign('xoops_mpageurl', TEAM_URL.'/teams.php');
$GLOBALS['xoopsTpl']->assign('team_upload_url', TEAM_UPLOAD_URL);

require __DIR__ . '/footer.php';
